@@ -37,6 +37,8 @@
 #define GENOMICSDB_EXPORT __attribute__((visibility("default")))
 
 #include <string>
+#include <vector>
+
 #include "genomicsdb_status.h"
 
 namespace genomicsdb {
@@ -70,6 +72,35 @@ GENOMICSDB_EXPORT ssize_t file_size(const std::string& filename);
  */
 GENOMICSDB_EXPORT int read_entire_file(const std::string& filename, void **buffer, size_t *length);
 
+/** Check whether workspace exists
+ * @param workspace storage URL
+ * @return true if given workspace exists, false otherwise
+ */ 
+GENOMICSDB_EXPORT bool workspace_exists(const std::string& workspace);
+
+/** Check whether an array in a given workspace exists
+ * @param workspace storage URL
+ * @param array_name
+ * @return true if array exists in the workspace, false otherwise
+ */
+GENOMICSDB_EXPORT bool array_exists(const std::string& workspace, const std::string& array_name);
+
+/**
+ * Get all array names under a workspace
+ * @param workspace storage URL
+ * @return vector of array names in the workspace
+ */
+GENOMICSDB_EXPORT std::vector<std::string> get_array_names(const std::string& workspace);
+
+/**
+ * Cache fragment metadata associated with array in a workspace. Used by the underlying storage system only
+ * when the workspace is a cloud URL for now.
+ * @param workspace storage URL
+ * @param array URL under workspace
+ * @return GENOMICSDB_OK for success, GENOMICSDB_ERR otherwise
+ */
+GENOMICSDB_EXPORT int cache_fragment_metadata(const std::string& workspace, const std::string& array_name);
+
 }
 
 
