@@ -487,7 +487,9 @@ const SingleCellTileDBIterator& SingleCellTileDBIterator::operator++() {
       begin_new_query_column_interval();
   } else {
     assert(m_in_simple_traversal_mode);
-    m_at_new_query_column_interval = false;
+    if (m_at_new_query_column_interval && m_cell_evaluated_with_filter_expression) {
+      m_at_new_query_column_interval = false;
+    }
     auto increment_done = advance_to_next_useful_cell(1u);
     //TileDB couldn't provide > 1 cell, must move to next column interval
     if (!increment_done)
@@ -517,21 +519,23 @@ bool SingleCellTileDBIterator::advance_to_next_useful_cell(const uint64_t min_nu
     std::vector<void *> buffers;
     std::vector<size_t> buffer_sizes;
     std::vector<int64_t> positions;
-    for (auto i=0; i<m_fields.size(); i++) {
+    for (auto i=0u; i<m_fields.size(); i++) {
       auto& genomicsdb_columnar_field = m_fields[i];
       auto buffer = get_buffer_and_index(i);
       if (genomicsdb_columnar_field.is_variable_length_field()) {
         buffers.push_back(const_cast<GenomicsDBBuffer *>(buffer.first)->get_offsets_pointer());
-        buffer_sizes.push_back(buffer.first->get_offsets_size_in_bytes());
-        positions.push_back((int64_t)buffer.second);
+        buffer_sizes.push_back((buffer.first->get_offsets_length()+1u)*sizeof(size_t));
       }
       buffers.push_back(const_cast<uint8_t *>(buffer.first->get_raw_pointer()));
       buffer_sizes.push_back(buffer.first->get_data_vector_size_in_bytes());
       positions.push_back((int64_t)buffer.second);
     }
-    if (tiledb_array_evaluate_cell(m_tiledb_array, buffers.data(), buffer_sizes.data(), positions.data()) != TILEDB_OK) {
-      m_cell_evaluated_with_filter_expression = false;
+    int rc;
+    if ((rc = tiledb_array_evaluate_cell(m_tiledb_array, buffers.data(), buffer_sizes.data(), positions.data())) == TILEDB_ERR) {
+      throw GenomicsDBIteratorException(std::string("Error while evaluating filter_expression")
+                                        + "\nTileDB error message : "+tiledb_errmsg);
     }
+    m_cell_evaluated_with_filter_expression = rc;
   }
 
   return true;
