@@ -1,6 +1,7 @@
 /**
  * The MIT License (MIT)
  * Copyright (c) 2016-2017 Intel Corporation
+ * Copyright (c) 2023 dātma, inc™
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy of
  * this software and associated documentation files (the "Software"), to deal in
@@ -721,8 +722,18 @@ bool VariantFieldHandler<DataType, CombineResultType>::concatenate_field(const V
       auto& vec = ptr->get();
       if (curr_result_size + vec.size() > m_concatenation_result.size())
         m_concatenation_result.resize(curr_result_size+vec.size());
+#if !defined(__clang__)
+      /* suppress gcc warnings for now:
+         src/main/cpp/include/utils/headers.h:56:54: warning: ‘void* memcpy(void*, const void*, size_t)’ writing to an object of type ‘__gnu_cxx::__alloc_traits<std::allocator<std::__cxx11::basic_string<char> >, std::__cxx11::basic_string<char> >::value_type’ {aka ‘class std::__cxx11::basic_string<char>’} with no trivial copy-assignment; use copy-assignment or copy-initialization instead [-Wclass-memaccess] */
+#  pragma GCC diagnostic push
+#  pragma GCC diagnostic ignored "-Wclass-memaccess"
+#endif
       memcpy_s(&(m_concatenation_result[curr_result_size]), vec.size()*sizeof(DataType), &(vec[0]),
 	  vec.size()*sizeof(DataType));
+
+#if !defined(__clang__)
+#  pragma GCC diagnostic pop
+#endif
       curr_result_size += vec.size();
     }
   }
@@ -794,8 +805,15 @@ bool VariantFieldHandler<DataType, CombineResultType>::collect_and_extend_fields
     //Valid field in a valid call
     if (curr_call.is_valid() && field_ptr.get() && field_ptr->is_valid()) {
       assert(field_ptr->get_raw_pointer());
+#if !defined(__clang__)
+#  pragma GCC diagnostic push
+#  pragma GCC diagnostic ignored "-Wclass-memaccess"
+#endif
       memcpy_s(&(m_extended_field_vector[extended_field_vector_idx]), field_ptr->length()*sizeof(DataType),
                field_ptr->get_raw_pointer(), field_ptr->length()*sizeof(DataType));
+#if !defined(__clang__)
+#  pragma GCC diagnostic pop
+#endif
       num_elements_inserted = field_ptr->length();
       extended_field_vector_idx += num_elements_inserted;
     }
@@ -850,7 +868,10 @@ bool HistogramFieldHandlerBase::compute_valid_histogram_sum_2D_vector(
     const FieldInfo* vid_field_info_bin,
     const FieldInfo* vid_field_info_count,
     std::vector<std::map<T1, CombineResultType>>& histogram_map_vec) {
+  // TODO: not sure how num_valid_elements was meant to be used, until then leave this out.
+#if 0
   auto num_valid_elements = 0ull;
+#endif
   auto num_calls_with_field = 0ull;
   assert(vid_field_info_bin->get_genomicsdb_type().get_tuple_element_type_index(0u) == std::type_index(typeid(T1)));
   assert(vid_field_info_count->get_genomicsdb_type().get_tuple_element_type_index(0u) == std::type_index(typeid(T2)));
@@ -886,9 +907,12 @@ bool HistogramFieldHandlerBase::compute_valid_histogram_sum_2D_vector(
 	if (is_bcf_valid_value<T1>(val_bin) && is_bcf_valid_value<T2>(val_count)) {
 	  auto iter_flag_pair = histogram_map.insert(std::pair<T1, CombineResultType>(val_bin, val_count));
 	  //Existing key
-	  if (!(iter_flag_pair.second))
-	    (*(iter_flag_pair.first)).second += val_count;
+	  if (!(iter_flag_pair.second)) {
+            (*(iter_flag_pair.first)).second += val_count;
+          }
+#if 0
 	  ++num_valid_elements;
+#endif
 	}
       }
       index_bin.advance_index_in_current_dimension();
