@@ -46,6 +46,8 @@
 #  include <nanoarrow/nanoarrow.h>
 #endif
 
+static std::string ctests_input_dir(GENOMICSDB_CTESTS_DIR);
+
 TEST_CASE_METHOD(TempDir, "utils", "[genomicsdb_utils]") {
   REQUIRE(genomicsdb::version().size() > 0);
   REQUIRE_THAT(genomicsdb::version(), Catch::Equals(GENOMICSDB_VERSION));
@@ -56,16 +58,41 @@ TEST_CASE_METHOD(TempDir, "utils", "[genomicsdb_utils]") {
 
   CHECK(genomicsdb::is_file(filename));
   CHECK(!genomicsdb::is_file(filename+".nonexistent"));
+  CHECK(!genomicsdb::is_file("az://non-existent-container/non-existent-file"));
   
   CHECK(genomicsdb::file_size(filename) == 11);
   CHECK(genomicsdb::file_size(filename+".new") == -1);
+  CHECK(genomicsdb::file_size("az://non-existent-container/non-existent-file") == -1);
   
   char *txt;
   size_t length;
   CHECK(genomicsdb::read_entire_file(filename, (void **)&txt, &length) == GENOMICSDB_OK);
   CHECK(length == 11);
   CHECK(hello_world == txt);
-  CHECK(genomicsdb::read_entire_file(filename+".another", (void **)txt, &length) == TILEDB_ERR);
+  CHECK(genomicsdb::read_entire_file(filename+".another", (void **)txt, &length) == GENOMICSDB_ERR);
+  CHECK(genomicsdb::read_entire_file("az://non-existent-container/non-existent-file", (void **)txt, &length) == GENOMICSDB_ERR);
+
+  auto ws = ctests_input_dir+"ws";
+
+  CHECK(genomicsdb::workspace_exists(ws));
+  CHECK(!genomicsdb::workspace_exists("non-existent-ws"));
+  CHECK(!genomicsdb::workspace_exists("az://non-existent-container/ws"));
+
+  auto array = "t0_1_2";
+  CHECK(genomicsdb::array_exists(ws, array));
+  CHECK(!genomicsdb::array_exists(ws, "non-existent-array"));
+  CHECK(!genomicsdb::array_exists("non-existent-ws", array));
+  CHECK(!genomicsdb::array_exists("az://non-existent-ws", array));
+
+  auto arrays = genomicsdb::get_array_names(ws);
+  CHECK(arrays.size() == 1);
+  CHECK(arrays[0] == "t0_1_2");
+  CHECK(genomicsdb::get_array_names("non-existent-ws").size() == 0);
+  CHECK(genomicsdb::get_array_names("az://non-existent-container/ws").size() == 0);
+
+  CHECK(genomicsdb::cache_fragment_metadata(ws, "t0_1_2") == GENOMICSDB_OK);
+  CHECK(genomicsdb::cache_fragment_metadata("non-existent-ws", "t0_1_2") == GENOMICSDB_ERR);
+  CHECK(genomicsdb::cache_fragment_metadata("az://non-existent-container/ws", "t0_1_2") == GENOMICSDB_ERR);
 }
 
 TEST_CASE("api empty_args", "[empty_args]") {
@@ -92,8 +119,6 @@ TEST_CASE("api empty_args", "[empty_args]") {
   }
 }
 
-static std::string ctests_input_dir(GENOMICSDB_CTESTS_DIR);
-
 static std::string workspace(ctests_input_dir+"ws");
 static std::string callset_mapping(ctests_input_dir+"callset_t0_1_2.json");
 static std::string vid_mapping(ctests_input_dir+"vid.json");
@@ -934,8 +959,8 @@ TEST_CASE("api query_variant_calls with JSONVariantCallProcessor", "[query_varia
   //  "HG00141":[["1",12141,null,"C/C","C"],["1",17385,null,"G/A","G"]],
   //  "HG01530":[["1",17385,76,"G/A","G"]],
   //  "HG01958":[["1",12145,null,"C/C","C"],["1",17385,120,"T/T","G"]]}
-  CHECK(output.length() == 207);
   printf("%lu %s\n\n", output.length(), output.c_str());
+  CHECK(output.length() == 207);
 
   JSONVariantCallProcessor json_processor1(JSONVariantCallProcessor::samples_with_ncalls);
   gdb->query_variant_calls(json_processor1, "", GenomicsDB::NONE);
@@ -975,26 +1000,26 @@ TEST_CASE("api query_variant_calls with JSONVariantCallProcessor", "[query_varia
   JSONVariantCallProcessor json_processor5(JSONVariantCallProcessor::all);
   gdb->query_variant_calls(json_processor5, "", GenomicsDB::NONE);
   output = json_processor5.construct_json_output();
-  // {"HG00141":{"CHR":["1","1"],"POS":[12141,17385],"AD":[null,58],"BaseQRankSum":[null,-2.0959999561309816],
+  // {"HG00141":{"CHR":["1","1"],"POS":[12141,17385],"AD":[null,"58, 22, 17"],"BaseQRankSum":[null,-2.0959999561309816],
   //             "ClippingRankSum":[null,-1.8589999675750733],"DP":[null,null],"DP_FORMAT":[2,80],"DS":["1","1"],
-  //             "FILTER":[null,0],"GQ":[0,99],"GT":["C/C","G/A"],"HaplotypeScore":[null,null],"InbreedingCoeff":[null,null],
-  //             "MIN_DP":[0,null],"MLEAC":[null,1],"MLEAF":[null,0.5],"MQ":[null,31.719999313354493],"MQ0":[null,8],
-  //             "MQRankSum":[null,-0.32899999618530276],"PGT":[null,"0|1"],"PID":[null,"17385_G_A"],"PL":[0,504],
+  //             "FILTER":[null,"0"],"GQ":[0,99],"GT":["C/C","G/A"],"HaplotypeScore":[null,null],"InbreedingCoeff":[null,null],
+  //             "MIN_DP":[0,null],"MLEAC":[null,"1, 5"],"MLEAF":[null,"0.500000, 1.200000"],"MQ":[null,31.719999313354493],"MQ0":[null,8],
+  //             "MQRankSum":[null,-0.32899999618530276],"PGT":[null,"0|1"],"PID":[null,"17385_G_A"],"PL":["0, 0, 0","504, 0, 9807, 678, 1870, 2548"],
   //             "QUAL":[null,475.7699890136719],"RAW_MQ":[null,5.5],"REF":["C","G"],
-  //             "ReadPosRankSum":[null,0.004999999888241291],"SB":[null,"[58, 0, 22, 0]"]},
-  //  "HG01530":{"CHR":["1"],"POS":[17385],"AD":[40],"BaseQRankSum":[1.0460000038146973],"ClippingRankSum":[-2.242000102996826],
+  //             "ReadPosRankSum":[null,0.004999999888241291],"SB":[null,"58, 0, 22, 0"]},
+  //  "HG01530":{"CHR":["1"],"POS":[17385],"AD":["40, 36, 0"],"BaseQRankSum":[1.0460000038146973],"ClippingRankSum":[-2.242000102996826],
   //             "DP":[76],"DP_FORMAT":[76],"DS":[null],"FILTER":[null],"GQ":[99],"GT":["G/A"],"HaplotypeScore":[null],
-  //             "InbreedingCoeff":[null],"MIN_DP":[null],"MLEAC":[1],"MLEAF":[0.5],"MQ":[59.369998931884769],"MQ0":[0],
-  //             "MQRankSum":[-0.4320000112056732],"PGT":[null],"PID":[null],"PL":[1018],"QUAL":[989.77001953125],
-  //             "RAW_MQ":[null],"REF":["G"],"ReadPosRankSum":[2.055000066757202],"SB":["[9, 31, 13, 23]"]},
-  //  "HG01958":{"CHR":["1","1"],"POS":[12145,17385],"AD":[null,0],"BaseQRankSum":[null,-2.0739998817443849],
+  //             "InbreedingCoeff":[null],"MIN_DP":[null],"MLEAC":["1, 0"],"MLEAF":["0.500000, 0.000000"],"MQ":[59.369998931884769],"MQ0":[0],
+  //             "MQRankSum":[-0.4320000112056732],"PGT":[null],"PID":[null],"PL":["1018, 0, 1116, 1137, 1224, 2361"],"QUAL":[989.77001953125],
+  //             "RAW_MQ":[null],"REF":["G"],"ReadPosRankSum":[2.055000066757202],"SB":["9, 31, 13, 23"]},
+  //  "HG01958":{"CHR":["1","1"],"POS":[12145,17385],"AD":[null,"0, 120, 37"],"BaseQRankSum":[null,-2.0739998817443849],
   //             "ClippingRankSum":[null,0.5550000071525574],"DP":[null,120],"DP_FORMAT":[3,120],"DS":["1",null],
-  //             "FILTER":[null,0],"GQ":[0,99],"GT":["C/C","T/T"],"HaplotypeScore":[null,null],"InbreedingCoeff":[null,null],
-  //             "MIN_DP":[0,null],"MLEAC":[null,2],"MLEAF":[null,1.0],"MQ":[null,29.81999969482422],"MQ0":[null,3],
-  //             "MQRankSum":[null,-1.36899995803833],"PGT":[null,"0|1"],"PID":[null,"17385_G_T"],"PL":[0,3336],
+  //             "FILTER":[null,"0"],"GQ":[0,99],"GT":["C/C","T/T"],"HaplotypeScore":[null,null],"InbreedingCoeff":[null,null],
+  //             "MIN_DP":[0,null],"MLEAC":[null,"2, 7"],"MLEAF":[null,"1.000000, 0.700000"],"MQ":[null,29.81999969482422],"MQ0":[null,3],
+  //             "MQRankSum":[null,-1.36899995803833],"PGT":[null,"0|1"],"PID":[null,"17385_G_T"],"PL":["0, 0, 0","3336, 358, 0, 4536, 958, 7349"],
   //             "QUAL":[null,3302.77001953125],"RAW_MQ":[null,2.5],"REF":["C","G"],"ReadPosRankSum":[null,-0.10100000351667404],
-  //             "SB":[null,"[0, 0, 0, 0]"]}}
-  CHECK(output.length() == 1805);
+  //             "SB":[null,"0, 0, 0, 0"]}}
+  CHECK(output.length() == 1999);
   printf("%lu %s\n\n", output.length(), output.c_str());
   delete gdb;
 
