@@ -1,5 +1,7 @@
 /**
- * The MIT License (MIT) Copyright (c) 2019-2020 Omics Data Automation, Inc.
+ * The MIT License (MIT)
+ * Copyright (c) 2019-2020 Omics Data Automation, Inc.
+ * Copyright (c) 2023 dātma, inc™
  *
  * <p>Permission is hereby granted, free of charge, to any person obtaining a copy of this software
  * and associated documentation files (the "Software"), to deal in the Software without restriction,
@@ -18,21 +20,12 @@
  */
 package org.genomicsdb.reader;
 
-import java.io.File;
-import java.io.IOException;
-import java.nio.file.Paths;
-import java.util.ArrayList;
-import java.util.List;
-import java.util.Map;
-
 import org.apache.commons.lang3.math.NumberUtils;
 import org.genomicsdb.exception.GenomicsDBException;
+import org.genomicsdb.model.Coordinates;
 import org.genomicsdb.model.Coordinates.GenomicsDBColumnInterval;
 import org.genomicsdb.model.Coordinates.GenomicsDBColumnOrInterval;
 import org.genomicsdb.model.Coordinates.TileDBColumnInterval;
-import org.genomicsdb.model.GenomicsDBExportConfiguration;
-import org.genomicsdb.model.GenomicsDBExportConfiguration.AnnotationSource;
-import org.genomicsdb.model.GenomicsDBExportConfiguration.GenomicsDBColumnOrIntervalList;
 import org.genomicsdb.reader.GenomicsDBQuery.Interval;
 import org.genomicsdb.reader.GenomicsDBQuery.Pair;
 import org.genomicsdb.reader.GenomicsDBQuery.VariantCall;
@@ -40,6 +33,14 @@ import org.testng.Assert;
 import org.testng.annotations.BeforeClass;
 import org.testng.annotations.Test;
 
+import java.io.File;
+import java.io.IOException;
+import java.nio.file.Paths;
+import java.util.ArrayList;
+import java.util.List;
+import java.util.Map;
+import static org.genomicsdb.model.GenomicsDBExportConfiguration.*;
+
 public class GenomicsDBQueryTest {
 
   static String inputsDir = Paths.get("target", "test", "inputs").toAbsolutePath().toString();
@@ -172,12 +173,12 @@ public class GenomicsDBQueryTest {
     long genomicsDBHandle = connectWithDPAttribute();
 
     List<Interval> intervals = query.queryVariantCalls(genomicsDBHandle, arrayName);
-    assert(intervals.size() == 0);
+    assert(intervals.size() == 1);
 
     List<Pair>columnRanges = new ArrayList<>();
     columnRanges.add(new Pair(0L, 1000000000L));
     intervals = query.queryVariantCalls(genomicsDBHandle, arrayName, columnRanges);
-    assert(intervals.size() == 0);
+    assert(intervals.size() == 1);
 
     List<Pair>rowRanges = new ArrayList<>();
     rowRanges.add(new Pair(0L, 3L));
@@ -200,7 +201,7 @@ public class GenomicsDBQueryTest {
     long genomicsDBHandle = connectWithDPandGTAttribute();
 
     List<Interval> intervals = query.queryVariantCalls(genomicsDBHandle, arrayName);
-    Assert.assertEquals(intervals.size(), 0);
+    Assert.assertEquals(intervals.size(), 1);
 
     List<Pair> columnRanges = new ArrayList<>();
     columnRanges.add(new Pair(0L, 1000000000L));
@@ -264,6 +265,74 @@ public class GenomicsDBQueryTest {
     query.disconnect(genomicsDBHandle);
   }
 
+  @Test
+  void testGenomicsDBVariantCallQueryWithPBExportConfig() throws IOException {
+    String workspace_PP = workspace+"_phased_ploidy";
+    Coordinates.ContigInterval interval = Coordinates.ContigInterval.newBuilder()
+        .setContig("1").setBegin(1).setEnd(100000).build();
+    RowRangeList rowRangeList = RowRangeList.newBuilder().addRangeList(RowRange.newBuilder()
+            .setLow(0L).setHigh(3L).build()).build();
+    ExportConfiguration exportConfiguration = ExportConfiguration.newBuilder()
+        .setWorkspace(workspace_PP)
+        .setVidMappingFile(vidMapping)
+        .setCallsetMappingFile(callsetMapping)
+        .setArrayName(arrayName)
+        .setSegmentSize(40)
+        .addQueryContigIntervals(interval)
+        .addQueryRowRanges(rowRangeList)
+        .build();
+
+    GenomicsDBQuery query = new GenomicsDBQuery();
+    long genomicsDBHandle = query.connectExportConfiguration(exportConfiguration);
+    Assert.assertTrue(genomicsDBHandle > 0);
+
+    List<Interval> intervals = query.queryVariantCalls(genomicsDBHandle);
+    Assert.assertEquals(intervals.size(), 1);
+    Assert.assertEquals(intervals.get(0).calls.size(), 5);
+    query.disconnect(genomicsDBHandle);
+
+    // With filter
+    exportConfiguration = ExportConfiguration.newBuilder()
+        .setWorkspace(workspace_PP)
+        .setVidMappingFile(vidMapping)
+        .setCallsetMappingFile(callsetMapping)
+        .setArrayName(arrayName)
+        .setQueryFilter("POS==17384 && REF==\"G\" && ALT|=\"A\" && resolve(GT, REF, ALT)&=\"G/A\"")
+        .setSegmentSize(40)
+        .addQueryContigIntervals(interval)
+        .addQueryRowRanges(rowRangeList)
+        .build();
+    query = new GenomicsDBQuery();
+    genomicsDBHandle = query.connectExportConfiguration(exportConfiguration);
+    Assert.assertTrue(genomicsDBHandle > 0);
+
+    intervals = query.queryVariantCalls(genomicsDBHandle);
+    Assert.assertEquals(intervals.size(), 1);
+    Assert.assertEquals(intervals.get(0).calls.size(), 2);
+    query.disconnect(genomicsDBHandle);
+
+    exportConfiguration = ExportConfiguration.newBuilder()
+        .setWorkspace(workspace_PP)
+        .setVidMappingFile(vidMapping)
+        .setCallsetMappingFile(callsetMapping)
+        .setArrayName(arrayName)
+        .setQueryFilter("NOT_ATTR=17384 && REF==\"G\" && ALT|=\"A\" && resolve(GT, REF, ALT)&=\"G/A\"")
+        .setSegmentSize(40)
+        .addQueryContigIntervals(interval)
+        .addQueryRowRanges(rowRangeList)
+        .build();
+    query = new GenomicsDBQuery();
+    genomicsDBHandle = query.connectExportConfiguration(exportConfiguration);
+    Assert.assertTrue(genomicsDBHandle > 0);
+
+    try {
+      intervals = query.queryVariantCalls(genomicsDBHandle);
+      Assert.fail();
+    } catch (GenomicsDBException e) {
+      // Expected Exception for bad filter
+    }
+  }
+
   @Test
   void testGenomicsDBGenerateVCF() throws IOException {
     GenomicsDBQuery query = new GenomicsDBQuery();
@@ -292,6 +361,8 @@ public class GenomicsDBQueryTest {
     }
 
     vcfFile.delete();
+
+    query.disconnect(genomicsDBHandle);
   }
 
   @Test
@@ -308,11 +379,13 @@ public class GenomicsDBQueryTest {
     Assert.assertTrue(vcfFile.length() > 0);
     Assert.assertTrue(vcfIndexFile.exists());
     Assert.assertTrue(vcfIndexFile.length() > 0);
+
+    query.disconnect(genomicsDBHandle);
   }
 
   @Test
   void testGenomicsDBGenerateVCFWithPBExportConfig() throws IOException {
-    GenomicsDBExportConfiguration.ExportConfiguration exportConfiguration = GenomicsDBExportConfiguration.ExportConfiguration.newBuilder()
+    ExportConfiguration exportConfiguration = ExportConfiguration.newBuilder()
         .setWorkspace(workspace)
         .setVidMappingFile(vidMapping)
         .setCallsetMappingFile(callsetMapping)
@@ -335,6 +408,52 @@ public class GenomicsDBQueryTest {
     Assert.assertTrue(vcfFile.length() > 0);
     Assert.assertTrue(vcfIndexFile.exists());
     Assert.assertTrue(vcfIndexFile.length() > 0);
+
+    query.disconnect(genomicsDBHandle);
+  }
+
+  @Test
+  void testGenomicsDBDemoWorkspace() throws IOException {
+    String ws = System.getenv("GENOMICSDB_DEMO_WS");
+    if (ws == null || ws.isEmpty()) {
+      return;
+    }
+    String arrayName = "allcontigs$1$3095677412";
+    Coordinates.ContigInterval interval = Coordinates.ContigInterval.newBuilder()
+            .setContig("17").setBegin(7571719).setEnd(7590868).build();
+    RowRangeList rowRangeList = RowRangeList.newBuilder().addRangeList(RowRange.newBuilder()
+            .setLow(0l).setHigh(200000l).build()).build();
+
+    String filters[] = {"",
+      "REF==\"A\"", "REF==\"A\" && ALT|=\"T\"",
+      "REF==\"A\" &&  ALT|=\"T\" && ISHOMALT",
+      "REF==\"A\" && ALT|=\"T\" && resolve(GT, REF, ALT)&=\"T/T\""
+    };
+    Long expected_calls[] = new Long[]{ 2962039L, 400432L, 82245L, 82245L, 69548L };
+    Assert.assertEquals(filters.length, expected_calls.length);
+
+    for (int i=0; i< filters.length; i++) {
+      Long startTime = System.currentTimeMillis();
+      ExportConfiguration exportConfiguration = ExportConfiguration.newBuilder()
+              .setWorkspace(ws)
+              .setVidMappingFile(ws + "/vidmap.json")
+              .setCallsetMappingFile(ws + "/callset.json")
+              .setArrayName(arrayName)
+              .setEnableSharedPosixfsOptimizations(true)
+              .setBypassIntersectingIntervalsPhase(true)
+              .setQueryFilter(filters[i])
+              .addQueryContigIntervals(interval)
+              .addQueryRowRanges(rowRangeList)
+              .build();
+      GenomicsDBQuery query = new GenomicsDBQuery();
+      long genomicsDBHandle = query.connectExportConfiguration(exportConfiguration);
+      Assert.assertTrue(genomicsDBHandle > 0);
+      List<Interval> intervals = query.queryVariantCalls(genomicsDBHandle);
+      Assert.assertEquals(intervals.size(), 1);
+      Assert.assertEquals(intervals.get(0).calls.size(), expected_calls[i].longValue());
+      System.out.println("Elapsed Time for "+filters[i]+(System.currentTimeMillis()-startTime)/1000+"s");
+      query.disconnect(genomicsDBHandle);
+    }
   }
 
   /**
@@ -346,7 +465,7 @@ public class GenomicsDBQueryTest {
   void testGenomicsDbVcfAnnotationService() {
     String dataSourceName = "dataSourceZero";
 
-    GenomicsDBExportConfiguration.ExportConfiguration exportConfiguration = GenomicsDBExportConfiguration.ExportConfiguration
+    ExportConfiguration exportConfiguration = ExportConfiguration
         .newBuilder()
         .setWorkspace(workspace)
         .setVidMappingFile(vidMapping)
@@ -380,7 +499,8 @@ public class GenomicsDBQueryTest {
     Assert.assertTrue(genomicsDBHandle > 0);
 
     List<Interval> intervals = query.queryVariantCalls(genomicsDBHandle, arrayName);
-    assert (intervals.size() == 0);
+    Assert.assertEquals(intervals.size(), 1);
+    Assert.assertEquals(intervals.get(0).calls.size(), 5);
 
     List<Pair> columnRanges = new ArrayList<>();
     columnRanges.add(new Pair(0L, 1000000000L));
@@ -389,7 +509,7 @@ public class GenomicsDBQueryTest {
     rowRanges.add(new Pair(0L, 3L));
 
     intervals = query.queryVariantCalls(genomicsDBHandle, arrayName, columnRanges, rowRanges);
-    assert (intervals.size() == 2);
+    Assert.assertEquals(intervals.size(), 1);
 
     int variantsAnnotated = 0;
 
@@ -426,14 +546,14 @@ public class GenomicsDBQueryTest {
       }
     }
 
-    Assert.assertEquals(variantsAnnotated, 6, "Expected six variants to have annotations");
+    Assert.assertEquals(variantsAnnotated, 3, "Expected six variants to have annotations");
 
     query.disconnect(genomicsDBHandle);
   }
 
   /**
    * Compare the annotations in the genomicFields map to the expected values
-   * 
+   *
    * @param genomicFields
    * @param field0
    * @param field1
@@ -488,7 +608,7 @@ public class GenomicsDBQueryTest {
 
   /**
    * Convert the comma separated GenomicFields["ALT"] value to an array of strings
-   * 
+   *
    * @param alt
    * @return
    */
@@ -507,7 +627,7 @@ public class GenomicsDBQueryTest {
   void testGenomicsDbVcfAnnotationServiceMissingVcfException() {
     String dataSourceName = "dataSource123";
 
-    GenomicsDBExportConfiguration.ExportConfiguration exportConfiguration = GenomicsDBExportConfiguration.ExportConfiguration
+    ExportConfiguration exportConfiguration = ExportConfiguration
         .newBuilder()
         .setWorkspace(workspace)
         .setVidMappingFile(vidMapping)
